Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidFormat = errors.New("invalid UOP file format") ErrInvalidIndex = errors.New("invalid index") ErrReaderClosed = errors.New("uop reader is closed") ErrEntryNotFound = errors.New("entry not found") ErrInvalidEntry = errors.New("invalid entry") )
Standard UOP format errors
Functions ¶
This section is empty.
Types ¶
type CompressionType ¶
type CompressionType int16
CompressionType represents the compression method used for a UOP entry
const ( CompressionNone CompressionType = 0 CompressionZlib CompressionType = 1 CompressionMythic CompressionType = 2 )
Compression flag constants
type Entry6D ¶
type Entry6D struct {
// contains filtered or unexported fields
}
Entry6D represents an entry in UOP files with 6 components including compression info
type Option ¶
type Option func(*Reader)
Option defines a function that configures a Reader.
func WithExtension ¶
WithExtension sets the file extension for the pattern.
func WithExtra ¶
func WithExtra() Option
WithExtra sets a flag to indicate if extra data is present in the entries.
func WithLength ¶ added in v0.0.6
WithLength sets the length of the index.
func WithStrict ¶
func WithStrict() Option
WithStrict sets a flag to indicate if the reader should perform strict entry validation.
Click to show internal directories.
Click to hide internal directories.